-  **v4.2.1** - 2025/2/6 - Parabolic correction set back to arithmetic mean
-  **v4.2** - 2025/1/19 - Change installation from setuptools to scikit-build-core. ESPL table automatically set on import and loaded when needed. New coefficients for polynomial in Binary Lensing; Polynomial roots are calculated after sorting from smallest to largest; Old parabolic correction calculated with harmonic mean; Contours with too large theoretical error are recalculated at different radii.
-  **v4.1.2** - 2024/11/22 - Bug corrected in TripleLightCurve for far sources.
-  **v4.1.1** - 2024/10/14 - Bug corrected in Keplerian orbit calculation; TriplLightCurveParallax included also for single-time calculation.
-  **v4.1** - 2024/09/28 - All functions collected in only one file VBMicrolensingLibrary; Factor 3 speed-up due to inline complex functions and optimizations in polynomial calculations; Increased stability for high-mag calculations with new patch in BinaryMagSafe.
-  **v4.0** - 2024/07/10 - First release
